==> pycharmPY-253.28294.336-EAP-CANDIDATE.zip: _sha512.py <==
# encoding: utf-8
# module _sha512
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/_sha512.cpython-37m-darwin.so
# by generator 1.147
# no doc
# no imports

# functions

def sha384(*args, **kwargs): # real signature unknown
    """ Return a new SHA-384 hash object; optionally initialized with a string. """
    pass

def sha512(*args, **kwargs): # real signature unknown
    """ Return a new SHA-512 hash object; optionally initialized with a string. """
    pass

# classes

class SHA384Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



class SHA512Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x105585248>'

__spec__ = None # (!) real value is "ModuleSpec(name='_sha512', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x105585248>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/_sha512.cpython-37m-darwin.so')"

==> pycharmPY-253.30387.8-EAP-CANDIDATE.zip: _sha512.py <==
# encoding: utf-8
# module _sha512
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python38/lib/python3.8/lib-dynload/_sha512.cpython-38-darwin.so
# by generator 1.147
# no doc
# no imports

# functions

def sha384(*args, **kwargs): # real signature unknown
    """ Return a new SHA-384 hash object; optionally initialized with a string. """
    pass

def sha512(*args, **kwargs): # real signature unknown
    """ Return a new SHA-512 hash object; optionally initialized with a string. """
    pass

# classes

class SHA384Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



class SHA512Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x1037cde50>'

__spec__ = None # (!) real value is "ModuleSpec(name='_sha512', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x1037cde50>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python38/lib/python3.8/lib-dynload/_sha512.cpython-38-darwin.so')"
